<a name="5F6tz"></a>

## 知蛛是什么？

- 知蛛知识图谱平台（以下简称知蛛），是蚂蚁的**金融知识图谱管理**平台，为算法和数据岗位提供高效业务知识建模和知识研发能力，以及为业务策略岗位提供交互式知识分析和决策推理能力，为用户提供**一站式的知识生命周期管理工具和应用服务**。

![截屏2023-06-05 07.40.47.png](https://intranetproxy.alipay.com/skylark/lark/0/2023/png/15256345/1685922356440-01063bd8-91ec-410c-9528-8950ee2d1132.png)
<a name="ndMKU"></a>

## 业务场景

- 知蛛作为蚂蚁机器智能团队基础性智能平台产品，已经支持了**蚂蚁大部分的业务场景**，如保险健康知识图谱、财富金融产品图谱、支付商家知识图谱、支付医疗图谱、支付黑产图谱、微贷企业图谱、智能资金图谱、安全风险图谱、消金知识图谱、技术风险图谱等。
- **推荐系统**，支付内容图谱通过建立用户，行为，内容关系提升搜索和推荐效果。
- **知识问答**，在财富安娜智能助理场景，通过构建人，企业，基金公司，基金经理，基金产品等信息满足用户对财富基金场景的智能问答。
- **安全风控**，大安全商户同店反作弊场景，通过图谱进行百亿级别知识推理，发现“一店多码”“一人多店”等套利行为。
- **智能决策**，保险智能健告项目，结合健康图谱，健告规则图谱，构建规则推理引擎，实现自动对健告规则进行解读，提升保险产品体验，有效降低人力资源投入。
- **合规自查**，监管合规场景，通过建立企业，法律条文，处罚事件，牌照，关注点等知识图谱，满足对外部事件预警，内部合规主动排查风险。
- **企业授信**，使用图推理算法，自动发现企业上下游关系，提高企业授信的覆盖率和准确率。
- **主体归一/链指**，保险智能理赔场景，使用图谱实现医院/疾病实体链指，知识归一，帮助发现相同医院疾病，提高理赔的准确率。
  :::tips
  知蛛领域图谱业务大图
  :::
  ![截屏2023-06-05 07.40.00.png](https://intranetproxy.alipay.com/skylark/lark/0/2023/png/15256345/1685922297054-4863ff79-c41c-4698-bad5-45ef5468447a.png)<br />**图谱业务介绍可以参考PPT：**[https://yuque.antfin-inc.com/zhmydk/help/awcgar#siw4w](https://yuque.antfin-inc.com/zhmydk/help/awcgar#siw4w)
- 知识建设情况：全平台知识约1W亿

![截屏2023-06-09 08.01.51.png](https://intranetproxy.alipay.com/skylark/lark/0/2023/png/15256345/1686268934931-62a3190d-e681-4d83-9cae-a2f413659feb.png)

- 蚂蚁核心知识建设现状：经过算法测算的高置信度知识，包括**用户、商家、地理位置、常识、金融事件、产业链**等；
- 其它**经过业务使用后认可的**高质量领域知识：金融安全风控（**账户、商户、企业、介质、案件、交易**等）、全域资金交易（**交易明细**类）、支付黑产画像（**黑设备、黑团伙**等）；
- 如需引用如上知识，可联系PD钰成，或各项目业务Owner。

<a name="FECDl"></a>

## 产品架构

- 产品地址：[https://akg.alipay.com/v2/home](https://akg.alipay.com/v2/home)
- 基本完成知识图谱一站式的构建和应用体系，并初步完成领域知识自动管理和超时空图谱能力建设，满足金融风控场景（商户/用户风险识别、黑产案件研判、反赌反诈反套现拦截、消费金融进件审核等）及营销场景（智能问诊/导诊、保险/理财产品推荐、小程序搜索推荐、认知圈人、睡眠户唤醒等）。

![](https://intranetproxy.alipay.com/skylark/lark/0/2023/jpeg/15256345/1686269793798-5737c68c-c95b-481b-90cd-dc2365b6f112.jpeg)

<a name="KID0Q"></a>

## 特色能力

- 知蛛提供的核心能力包括：
  - **图形化操作，降低产品的使用门槛**。可视化业务知识建模和流程化知识加工，可自助研发的本体、概念建模及知识抽取、标化、链指、归一、挂载等算子，支持结构化、半/非结构化数据的图谱构建；以及跨领域知识管理，包括知识演化、复用、融合等能力；**提升Schema设计效率，快速从关系数据库转为图谱结构**。
  - **知识生产&应用生命周期**。提供从知识产生，到知识推理、服务完整知识应用能力，支持产品接入、Java/Python SDK（Knext）接入等开放平台能力。**提升工程同学的业务平台的研发效率**。
  - **交互知识可视化分析**，提供知识查询，关联分析，决策路径分析、知识模式匹配、图智能分析工具等；**帮助专家快速发现和定位到异常模式。**
  - **海量知识推理能力。**支持超大规模知识推理能力，包括专家规则推理、图谱表示学习推理、规则&模型融合的推理等，支持多引擎适配[tensorflow(AlpsGraphML),pytorch(AntMMF, pyG)]并提供KGRLib SDK能力支持业务算法的二次开发和高效接入。**提升算法研发效率。**
  - **构建领域知识底盘。**基于单业务场景构建多下游任务可复用、可共享的统一知识底盘，支持多样化的推理任务、知识分析、知识服务等。
  - **跨业务知识复用。**基于图谱的链指&融合算子，实现跨业务的图谱实体融合、关系链指、实体复用等，做到可连既可用，降低业务复用知识的成本。
  - **金融Schema沉淀**。针对金融场景，统一沉淀知识的Schema，让业务能够使用更多关联的数据，已经满足更加丰富的支持推理。
  - **丰富行业解决方案**。蚂蚁丰富的金融场景，已经在保险，财富，微贷，支付，监管合规，大安全，有深入知识图谱应用，详细见：[https://yuque.antfin.com/zhmydk/help/vdqcb3](https://yuque.antfin.com/zhmydk/help/vdqcb3)

![](https://intranetproxy.alipay.com/skylark/lark/0/2023/jpeg/15256345/1686269862636-c473cc81-cccc-4268-b17e-198e5a5bc44a.jpeg)

<a name="eee0c26c"></a>

## 目标用户

- **算法工程师**，平台提供规则推理、图算法组件、知识融合等能力，满足快速知识推理、算法研发/验证的需求。
- **数据工程师**，满足知识建模（构建实体类型以及关系类型，类似数据架构师做的数据建模），以及知识研发（将外部数据，比如ODPS，加工并导入到图谱中，生成具体的实体实例和关系实例）的需求。
- **研发工程师，**满足领域系统链路对接（SDK)所需的构建&推理任务部署、分析查询及高性能在线服务等。
- **策略工程师**，平台提供知识分析、知识推理等工具，满足从知识及其关联关系中洞察线索、沉淀专家经验的需求。

<a name="86fcc422"></a>

## 核心流程

![image.png](https://intranetproxy.alipay.com/skylark/lark/0/2019/png/399/1568694006410-98974449-b375-4802-ac07-b74f4724b4de.png)

- **知识建模**，提供实体，关系，属性的Schema建模能力，支持图形化和文本化两种模式。
- **知识导入**，提供对多种外部数据源导入到图谱的能力，支持实体归一，属性转换，知识打标等。
- **知识分析**，提供通用的知识查询，关联分析，路径分析，以及高级Gremlin，规则推理，GraphEmbeding算法推理等工具支持。
- **应用服务**，提供在线服务化，接口调试，灰度等在线服务能力。
- **知识运维**，对知识导入任务，推理任务进行日常示例的运维操作。

<a name="mjuMh"></a>

## 产品荣誉

<a name="4cad22937d443227b1aa58c55180e34f"></a>

### 获奖

- 2019   蚂蚁金融知识图谱平台 第四届人工智能领袖峰会（AIC）应用示范奖
- 2019  蚂蚁看见项目风云榜第二名 （TOP 10)
- 2020  蚂蚁金融知识图谱平台-知蛛 全球人工智能产品应用博览会创新产品 金奖
- 2021年蚂蚁金融知识图谱平台通过CESI知识图谱构建平台能力和应用平台能力认证
- 2021年蚂蚁与网商银行联合申报的《事理图谱在信贷风控中的应用》入选电子四院的《知识图谱优秀实践案例》，网商银行荣获“知识先锋企业”
- FY21财年，大安全风险知识图谱入选蚂蚁技术大事记
- Forrester：“蚂蚁知识图谱ⅹ网商银行”成为金融科技标杆案例。
- FY21财年，“资金图谱-资金追踪项目”荣获智能资金事业部总裁特别奖
- FY21财年，大安全风险知识图谱荣获T-STAR年度数据科学奖
- CY21，蚂蚁知识图谱技术能力被IDC点赞
- CY22，与支付安全团队合作支付安全知识图谱获得super-C蜀道同行奖
- CY22，蚂蚁知识图谱获得super-C锐意创新奖
- CY23，提名上海金融创新成果奖“支付安全风险全链路智能对抗体系创新与应用”

<a name="51509e1a2cbb4d90f84407ca90fa9ecc"></a>

### 软著

- 2019SR1264797  蚂蚁金服金融知识图谱融合推理软件
- 2019SR1264807  蚂蚁金服金融知识图谱实时构建软件
- 2021SR0138788  蚂蚁金融事理图谱及推理应用平台

<a name="a568d4c9cfadb05ea79f06f6247fbf00"></a>

### 产出软件标准

| **序号** |   **合作机构**   | **标准类别** |        **标准名称**        |
|--------|--------------|----------|------------------------|
| 1      | IEEE P2807.1 | 国际标准     | 《知识图谱技术要求与测试评估规范》      |
| 2      | IEEE P2807.2 | 国际标准     | 《金融知识图谱应用指南》           |
| 3      | 信标委          | 国标       | 《畜牧知识图谱构建与应用要求》        |
| 4      | 信标委          | 国标       | 《信息技术 人工智能 知识图谱存储技术要求》 |
| 5      | CCSA         | 行标       | 《基于知识图谱的电信运营商数据管理技术要求》 |
| 6      | CCSA         | 行标       | 《基于人工智能的知识图谱系统技术要求》    |
| 7      | CCSA         | 团标       | 《基于人工智能的知识图谱系统技术框架》    |
| 8      | AllA         | 团标       | 《金融知识图谱系统技术要求》         |
| 9      | 金科联盟         | 团标       | 《金融知识图谱构建和应用指南》        |
| 10     | 支付清算协会       | 团标       | 《基于知识图谱的收单风险防控技术框架》    |
| 11     | 中电标协         | 团标       | 《金融知识图谱产品检测技术规范》       |
| 12     | 金科联盟         | 研究报告     | 《知识图谱在金融领域的应用研究》       |
| 13     | 电子四院         | 白皮书      | 《知识图谱互联互通白皮书》          |

<a name="t38ZC"></a>

### 专利

工程技术已申请70+专利；算法已申请20+专利，已授权的5+专利。
